@@ -1,36 +1,46 @@
 use strict;
 use warnings;
 package Data::Rx::CoreType::all;
-our $VERSION = '0.100110';
-use base 'Data::Rx::CoreType';
+{
+  $Data::Rx::CoreType::all::VERSION = '0.200002';
+}
+use parent 'Data::Rx::CoreType';
 # ABSTRACT: the Rx //all type
 
 use Scalar::Util ();
 
-sub new_checker {
-  my ($class, $arg, $rx) = @_;
+sub guts_from_arg {
+  my ($class, $arg, $rx, $type) = @_;
 
   Carp::croak("unknown arguments to new")
     unless Data::Rx::Util->_x_subset_keys_y($arg, { of  => 1});
 
-  my $self = bless { } => $class;
-
   Carp::croak("no 'of' parameter given to //all") unless exists $arg->{of};
 
   my $of = $arg->{of};
 
   Carp::croak("invalid 'of' argument to //all") unless
     defined $of and Scalar::Util::reftype $of eq 'ARRAY' and @$of;
-    
-  $self->{of} = [ map {; $rx->make_schema($_) } @$of ];
 
-  return $self;
+  return { of => [ map {; $rx->make_schema($_) } @$of ] };
 }
 
-sub check {
+sub assert_valid {
   my ($self, $value) = @_;
-  
-  $_->check($value) || return for @{ $self->{of} };
+
+  my @subchecks;
+  for my $i (0 .. $#{ $self->{of} }) {
+    push @subchecks, [
+      $value,
+      $self->{of}[$i],
+      {
+        check_path => [ [ 'of', 'key'], [ $i, 'index' ] ],
+      }
+    ];
+  }
+
+  $self->perform_subchecks(\@subchecks);
+
   return 1;
 }
 
@@ -47,15 +57,15 @@ Data::Rx::CoreType::all - the Rx //all type
 
 =head1 VERSION
 
-version 0.100110
+version 0.200002
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
