@@ -1,14 +1,16 @@
 use strict;
 use warnings;
 package Data::Rx::CoreType::bool;
-our $VERSION = '0.100110';
-use base 'Data::Rx::CoreType';
+{
+  $Data::Rx::CoreType::bool::VERSION = '0.200002';
+}
+use parent 'Data::Rx::CoreType';
 # ABSTRACT: the Rx //bool type
 
-sub check {
+sub assert_valid {
   my ($self, $value) = @_;
 
-  return(
+  return 1 if (
     defined($value)
     and ref($value)
     and (
@@ -19,6 +21,12 @@ sub check {
       eval { $value->isa('boolean') }
     )
   );
+
+  $self->fail({
+    error   => [ qw(type) ],
+    message => "found value was not a bool",
+    value   => $value,
+  });
 }
 
 sub subname   { 'bool' }
@@ -34,15 +42,15 @@ Data::Rx::CoreType::bool - the Rx //bool type
 
 =head1 VERSION
 
-version 0.100110
+version 0.200002
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
