@@ -1,17 +1,28 @@
 use strict;
 use warnings;
 package Data::Rx::CoreType::int;
-our $VERSION = '0.100110';
-use base 'Data::Rx::CoreType::num';
+{
+  $Data::Rx::CoreType::int::VERSION = '0.200002';
+}
+use parent 'Data::Rx::CoreType::num';
 # ABSTRACT: the Rx //int type
 
 sub subname   { 'int' }
 
-sub check {
+sub __type_fail {
   my ($self, $value) = @_;
-  return unless $self->SUPER::check($value);
-  return unless $value == int $value;
-  return 1;
+  $self->fail({
+    error   => [ qw(type) ],
+    message => "value is not an integer",
+    value   => $value,
+  });
+}
+
+sub _value_is_of_type {
+  my ($self, $value) = @_;
+
+  return unless $self->SUPER::_value_is_of_type($value);
+  return ($value == int $value);
 }
 
 1;
@@ -25,15 +36,15 @@ Data::Rx::CoreType::int - the Rx //int type
 
 =head1 VERSION
 
-version 0.100110
+version 0.200002
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
