@@ -1,14 +1,22 @@
 use strict;
 use warnings;
 package Data::Rx::CoreType::nil;
-our $VERSION = '0.100110';
-use base 'Data::Rx::CoreType';
+{
+  $Data::Rx::CoreType::nil::VERSION = '0.200002';
+}
+use parent 'Data::Rx::CoreType';
 # ABSTRACT: the Rx //nil type
 
-sub check {
+sub assert_valid {
   my ($self, $value) = @_;
 
-  return ! defined $value;
+  return 1 if ! defined $value;
+
+  $self->fail({
+    error   => [ qw(type) ],
+    message => "found value is defined",
+    value   => $value,
+  });
 }
 
 sub subname   { 'nil' }
@@ -24,15 +32,15 @@ Data::Rx::CoreType::nil - the Rx //nil type
 
 =head1 VERSION
 
-version 0.100110
+version 0.200002
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
