@@ -1,22 +1,36 @@
 use strict;
 use warnings;
 package Data::Rx::CoreType::one;
-our $VERSION = '0.100110';
-use base 'Data::Rx::CoreType';
+{
+  $Data::Rx::CoreType::one::VERSION = '0.200002';
+}
+use parent 'Data::Rx::CoreType';
 # ABSTRACT: the Rx //one type
 
-sub check {
+sub assert_valid {
   my ($self, $value) = @_;
 
-  return if ! defined $value;
-  return if ref $value and ! (
+  if (! defined $value) {
+    $self->fail({
+      error   => [ qw(type) ],
+      message => "found value is undef",
+      value   => $value,
+    });
+  }
+
+  return 1 unless ref $value and ! (
     eval { $value->isa('JSON::XS::Boolean') }
     or
     eval { $value->isa('JSON::PP::Boolean') }
     or
     eval { $value->isa('boolean') }
   );
-  return 1;
+
+  $self->fail({
+    error   => [ qw(type) ],
+    message => "found value is a reference/container type",
+    value   => $value,
+  });
 }
 
 sub subname   { 'one' }
@@ -32,15 +46,15 @@ Data::Rx::CoreType::one - the Rx //one type
 
 =head1 VERSION
 
-version 0.100110
+version 0.200002
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
